"use client"
import { AppRouterCacheProvider } from "@mui/material-nextjs/v13-appRouter";
import { ThemeProvider } from "@mui/material/styles";
import theme from "../theme";
import "./globals.scss";
import { Provider } from 'react-redux';
import store from "@/services/store";
import AuthGuard from "@/hoc/authGuard/authGuard";
import { useRouter } from "next/navigation";
import { useEffect } from "react";

interface RootLayoutProps {
  children: React.ReactNode;
}

function RootLayout(props: RootLayoutProps): JSX.Element {
  const router = useRouter();
  const { children } = props;

  useEffect(() => {

    const token = localStorage.getItem('token');
    if (!token) {
      router.push('/log-in');
    } else {
      router.replace('/home');
    }
  }, [router])
  return (
    <html lang="en">
      <body>
        <Provider store={store}>
          <AppRouterCacheProvider>
            <ThemeProvider theme={theme}>{children}</ThemeProvider>
          </AppRouterCacheProvider>
        </Provider>
      </body>
    </html>
  );
}
export default AuthGuard(RootLayout);
