// components/CustomTextField.tsx
import React from 'react';
import TextField from '@mui/material/TextField';
import { Controller } from 'react-hook-form';
import { styled } from "@mui/material/styles";

interface CustomTextFieldProps {
  name: string;
  control: any;
  label: string;
  type?: string;
  error?: boolean;
  helperText?: string;
}

// Define your styled component
const CssTextField = styled(TextField)({
  width: "100%",
  "& label.Mui-focused": {
    color: "var(--primary)",
  },
  "& .MuiInputBase-root": {
    borderRadius: 8,
  },
  "& .MuiOutlinedInput-root": {
    "& fieldset": {
      borderColor: "var(--input-border-default)",
    },
    "&:hover fieldset": {
      borderColor: "var(--input-border-hover)",
    },
    "&.Mui-focused fieldset": {
      borderColor: "var(--primary)",
    },
  },
});

const CustomTextField: React.FC<CustomTextFieldProps> = ({ name, control, label, type = 'text', error, helperText }) => {
  return (
    <Controller

      name={name}
      control={control}
      render={({ field }) => (
        <CssTextField
          autoComplete='off'
          {...field}
          label={label}
          type={type}
          error={error}
          helperText={helperText}
          variant="outlined"
          fullWidth
        />
      )}
    />
  );
};

export default CustomTextField;
